@@ -53,7 +53,10 @@ def get_aza_fundamentals(stock_tic):
         print("Did second thing work?")
 
     try:
+        import time
+        time.sleep(2)
         driver.get(stock_url)
+        time.sleep(2)
         print("Sucessfully got stock page")
     except Exception as e:
         print(stock_url)
